Struct ab_glyph::GlyphImage [−][src]
pub struct GlyphImage<'a> {
pub origin: Point,
pub scale: f32,
pub data: &'a [u8],
pub format: GlyphImageFormat,
}Expand description
A pre-rendered image of a glyph, usually used for emojis or other glyphs that can’t be represented only using an outline.
Fields
origin: PointOffset of the image from the normal origin (top at the baseline plus ascent), measured in pixels at the image’s current scale.
scale: f32Current scale of the image in pixels per em.
data: &'a [u8]Raw image data (not a bitmap).
format: GlyphImageFormatFormat of the raw data.